@@ -275,15 +275,15 @@ class ApiGatewayToKinesisStreamsProps:
         :summary: The properties for the ApiGatewayToKinesisStreamsProps class.
         '''
         if isinstance(api_gateway_props, dict):
-            api_gateway_props = RestApiProps(**api_gateway_props)
+            api_gateway_props = aws_cdk.aws_apigateway.RestApiProps(**api_gateway_props)
         if isinstance(kinesis_stream_props, dict):
-            kinesis_stream_props = StreamProps(**kinesis_stream_props)
+            kinesis_stream_props = aws_cdk.aws_kinesis.StreamProps(**kinesis_stream_props)
         if isinstance(log_group_props, dict):
-            log_group_props = LogGroupProps(**log_group_props)
+            log_group_props = aws_cdk.aws_logs.LogGroupProps(**log_group_props)
         if isinstance(put_record_request_model, dict):
-            put_record_request_model = ModelOptions(**put_record_request_model)
+            put_record_request_model = aws_cdk.aws_apigateway.ModelOptions(**put_record_request_model)
         if isinstance(put_records_request_model, dict):
-            put_records_request_model = ModelOptions(**put_records_request_model)
+            put_records_request_model = aws_cdk.aws_apigateway.ModelOptions(**put_records_request_model)
         if __debug__:
             type_hints = typing.get_type_hints(ApiGatewayToKinesisStreamsProps.__init__)
             check_type(argname="argument api_gateway_props", value=api_gateway_props, expected_type=type_hints["api_gateway_props"])
